@@ -33,7 +33,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.36';
+our $VERSION = '2.37';
 
 =head1 SYNOPSIS
 
@@ -84,8 +84,8 @@ has 'outdir' => (
     is => 'rw',
     isa => 'Str',
     required => 1,
-#    default => sub {return getcwd() },
-    default => sub { return "$ENV{HOME}/hpcjobs" },
+    default => sub {return getcwd()."/logs" },
+    #    default => sub { return "$ENV{HOME}/hpcjobs" },
     documentation => q{Directory to write out files.},
     trigger => \&_set_outdir,
 );
@@ -133,15 +133,35 @@ has 'procs' => (
     documentation => q{Total number of running jobs allowed at any time. The command 'wait' can be used to have a variable number of children running.}
 );
 
+=head2 job_scheduler_ID
 
-has 'verbose' => (
+Job Scheduler ID running the script. Passed to slurm for mail information
+
+=cut
+
+has 'job_scheduler_id' => (
     is => 'rw',
-    isa => enum([qw[0 1]]),
+    isa => 'Str|Undef',
+    default => sub { return $ENV{SLURM_JOB_ID} || $ENV{PBS_JOBID} || undef; },
     required => 1,
-    default => 1,
-    documentation => q{Level of verbosity},
+    documentation => q{This defaults to your current Job Scheduler ID. Ignore this if running on a single node}
 );
 
+has 'show_processid' => (
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+    documentation => q{Show the process ID per logging message. This is useful when aggregating logs.}
+);
+
+#has 'verbose' => (
+    #is => 'rw',
+    #isa => enum([qw[0 1]]),
+    #required => 1,
+    #default => 1,
+    #documentation => q{Level of verbosity},
+#);
+
 =head1 Internal VARIABLES
 
 You shouldn't be calling these directly.
@@ -194,7 +214,7 @@ has 'logfile' => (
 has 'logname' => (
     isa => 'Str',
     is => 'rw',
-    default => 'prunner_logs',
+    default => 'hpcrunner_logs',
 );
 
 =head1 Subroutines
@@ -349,8 +369,16 @@ sub _log_commands {
 
     $DB::single=2;
 
-    $logger->debug("Starting job ".$self->counter." with PID $cmdpid");
-    $logger->debug("Cmd is ".$self->cmd);
+
+    #if($self->show_processid){
+        #$logger->debug("Starting job ".$self->counter." with PID $cmdpid\nCmd is ".$self->cmd);
+    #}
+    #else{
+        #$logger->debug("Starting job ".$self->counter." with PID $cmdpid");
+        #$logger->debug("Cmd is ".$self->cmd);
+    #}
+
+    $self->log_messages($logger, "debug", "Starting Job: ".$self->counter." \nCmd is ".$self->cmd, $cmdpid);
 
     $logger->debug("@ is ".$@) if $@;
 
@@ -369,7 +397,8 @@ sub _log_commands {
             my $len = sysread $fh, $line, 4096;
             if(not defined $len){
                 # There was an error reading
-                $logger->fatal("Error from child: $!");
+                #$logger->fatal("Error from child: $!");
+                $self->log_messages($logger, "fatal", "Error from child: $!" , $cmdpid)
             } elsif ($len == 0){
                 # Finished reading from this FH because we read
                 # 0 bytes.  Remove this handle from $sel.
@@ -377,9 +406,11 @@ sub _log_commands {
                 next;
             } else { # we read data alright
                 if($fh == $outfh) {
-                    $logger->info($line);
+                    #$logger->info($line);
+                    $self->log_messages($logger, "info", $line, $cmdpid)
                 } elsif($fh == $errfh) {
-                    $logger->error($line);
+                    #$logger->error($line);
+                    $self->log_messages($logger, "error", $line, $cmdpid)
                 } else {
                     $logger->fatal("Shouldn't be here!\n");
                 }
@@ -391,18 +422,34 @@ sub _log_commands {
     my $exitcode = $?;
 
     $DB::single=2;
-    $logger->debug("Finishing job ".$self->counter." with PID $cmdpid and ExitCode $exitcode");
+
+    #$logger->debug("Finishing job ".$self->counter." with PID $cmdpid and ExitCode $exitcode");
+    $self->log_messages($logger, "debug", "Finishing job ".$self->counter." with ExitCode $exitcode", $cmdpid);
 
     my $dt2 = DateTime->now();
     my $duration = $dt2 - $dt1;
     my $format = DateTime::Format::Duration->new(
         pattern => '%Y years, %m months, %e days, %H hours, %M minutes, %S seconds'
     );
-    $logger->info("Total execution time ".$format->format_duration($duration));
+
+    #$logger->info("Total execution time ".$format->format_duration($duration));
+    $self->log_messages($logger, "info", "Total execution time ".$format->format_duration($duration), $cmdpid);
 
     return $exitcode;
 }
 
+sub log_messages{
+    my($self, $logger, $level, $message, $cmdpid)  = @_;
+
+    if($self->show_processid){
+        $logger->$level("PID: $cmdpid\t$message");
+    }
+    else{
+        $logger->$level($message);
+    }
+
+}
+
 
 #__PACKAGE__->meta->make_immutable;
 1;
